@@ -115,8 +115,8 @@ class PrintSitePlugin(BasePlugin):
 
     def on_nav(self, nav, config, files, **kwargs):
 
-        # Save the (order of) pages in the navigation before adding the print page
-        self.renderer.pages = nav.pages.copy()  # nav_pages
+        # Save the (order of) pages and sections in the navigation before adding the print page
+        self.renderer.items = nav.items
 
         # Optionally add the print page to the site navigation
         if self.config.get("add_to_navigation"):
