@@ -114,7 +114,7 @@ def get_page_key(page_url):
     return page_key
 
 
-def fix_internal_links(html, page_url):
+def fix_internal_links(html, page_url, directory_urls):
     """
     Updates links to internal pages to anchor links.
     This ensures internal links all point to locations inside the print page. 
@@ -122,6 +122,7 @@ def fix_internal_links(html, page_url):
     Args:
         html (str): HTML of page
         page_url (str): URL of the page 
+        directory_urls (bool): Whether the mkdocs sites is using directory urls, see https://www.mkdocs.org/user-guide/configuration/?#use_directory_urls
 
     Returns:
         html (str): HTML of part of the print page with working internal links
@@ -138,16 +139,26 @@ def fix_internal_links(html, page_url):
         if is_external(url):
             continue
         elif is_anchor(url):
+            # This is an anchor link within a mkdocs page
             url = "#" + page_key + "-" + url[1:]
         else:
-            url = url_to_anchor(url)
+            # This is a link to another mkdocs page
+            # url 'a/#anchor-link' should become '#a-anchor-link'
+            url_from_root = os.path.normpath(os.path.join('/',url))
+            url_paths = url_from_root[1:].split("#")
+            assert len(url_paths) <= 2
+            page_url = url_paths[0]
+            url = '#' + get_page_key(page_url)
+            if len(url_paths) == 2:
+                url += "-" + url_paths[1]
+            
 
         # Insert back any HTML between '<a' and 'href=', like "class='id'"
         other_html = m.group(1)
         if other_html is None:
             other_html = ""
-
         new_string = '<a %s href="%s"' % (other_html, url)
+        
         html = html.replace(m.group(), new_string)
 
     # All instances of id="#anchor" to id="#pagename-anchor"
@@ -165,9 +176,6 @@ def fix_internal_links(html, page_url):
 
         html = html.replace(match_text, new_text)
 
-    # Finally, insert new anchor for each page
-    html = ('<section class="print-page" id="%s">' % page_key) + html + "</section>"
-
     ### Loop over all images src attributes
     # This fixes images in the print page.
     # Example regex https://regex101.com/r/TTRsVW/1
@@ -183,9 +191,16 @@ def fix_internal_links(html, page_url):
         img_text = m.group()
         
         new_url = os.path.normpath(os.path.join(os.path.dirname(page_url), img_src))
+        
+        if directory_urls:
+            new_url = '../' + new_url
+            
         new_text = img_text.replace(img_src, new_url)
 
         html = html.replace(img_text, new_text)
 
 
+    # Finally, insert new anchor for each page
+    html = ('<section class="print-page" id="%s">' % page_key) + html + "</section>"
+
     return html
